from django.conf.urls.defaults import *

# Uncomment the next two lines to enable the admin:
from django.contrib import admin
admin.autodiscover()

from widelands.mainpage.views import mainpage

from widelands.news.feeds import NewsPostsFeed
from widelands.wiki.feeds import RssHistoryFeed
from django.views.generic.simple import redirect_to

feeds = {
    'news': NewsPostsFeed,

    # Wiki has it's own set of feeds
}

urlpatterns = patterns('',
    # Uncomment the next line to enable the admin:
    (r'^admin/', include(admin.site.urls)),

    # Django builtin / Registration
    # overwrite registration with own implementation
    url (r'^accounts/register/$', 'mainpage.views.register', name='registration_register'),
    (r'^accounts/', include('registration.backends.default.urls')),
    (r'^feeds/(?P<url>.*)/$', 'django.contrib.syndication.views.feed', {'feed_dict': feeds}),

    # 3rd party, unmodified
    (r'^notification/', include('notification.urls')),
    # (r'^stats/', include('simplestats.urls')),
    (r'^messages/', include('django_messages.urls')),
    (r'^threadedcomments/', include('threadedcomments.urls')),
    (r'^docs/', include('sphinxdoc.urls')),

    # 3rd party, modified for widelands
    (r'^wiki/', include('wiki.urls')),
    (r'^news/', include('news.urls')),
    (r'^forum/', include('pybb.urls')),

    # WL specific:
    url(r'^$', mainpage, name="mainpage"),
    url(r'^changelog/$', "mainpage.views.changelog", name="changelog"),
    url(r'^developers/$', "mainpage.views.developers", name="developers"),
    url(r'^help/(?P<path>.*)', redirect_to, { "url": "/encyclopedia/%(path)s", "permanent": True }), # to not break old links
    url(r'^encyclopedia/', include("wlhelp.urls")),
    url(r'^webchat/', include("wlwebchat.urls")),
    url(r'^images/', include("wlimages.urls")),
    url(r'^profile/', include("wlprofile.urls")),
    url(r'^search/', include("wlsearch.urls")),
    url(r'^poll/', include("wlpoll.urls")),
    url(r'^maps/', include("wlmaps.urls")),
    url(r'^screenshots/', include("wlscreens.urls")),
    url(r'^ggz/', include("wlggz.urls")),
)

try:
    from local_urls import *
    urlpatterns += local_urlpatterns
except ImportError:
    pass

